==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/List.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
var List = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(List, _super);
    function List() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(List.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(List.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.n = this.d;
        },
        enumerable: false,
        configurable: true
    });
    List.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(List.prototype, "a", {
        get: function () {
            var ret_ = this.c.m("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.c.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.c.u("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    List.prototype.f = function () {
        this.nativeElement.connectedCallback();
    };
    List.$t = markType(List, 'List', BaseElement.$);
    return List;
}(BaseElement));
export { List };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/List.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { SizableComponentSize_$type } from "./SizableComponentSize";
/**
 * @hidden
 */
var List = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(List, _super);
    function List() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.b = new WCNativeHelper();
        _this.d = null;
        return _this;
    }
    Object.defineProperty(List.prototype, "c", {
        get: function () {
            return this.b;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(List.prototype, "nativeElement", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
            this.b.o = this.d;
        },
        enumerable: false,
        configurable: true
    });
    List.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(List.prototype, "a", {
        get: function () {
            var ret_ = this.c.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.c.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.c.v("size", value_);
        },
        enumerable: false,
        configurable: true
    });
    List.prototype.f = function () {
        this.nativeElement.connectedCallback();
    };
    List.$t = markType(List, 'List', BaseElement.$);
    return List;
}(BaseElement));
export { List };
